@@ -88,18 +88,18 @@ impl<'a> Context<'a> {
     self.last_token_end = self.scanner.token_end();
 
     // store the comment for the previous token end, and current token start
-    if let Some(comments) = self.comments.as_mut() {
-      if let Some(current_comments) = self.current_comments.take() {
-        let current_comments = Rc::new(current_comments);
-        comments.insert(previous_end, current_comments.clone());
-        comments.insert(self.scanner.token_start(), current_comments);
-      }
+    if let Some(comments) = self.comments.as_mut()
+      && let Some(current_comments) = self.current_comments.take()
+    {
+      let current_comments = Rc::new(current_comments);
+      comments.insert(previous_end, current_comments.clone());
+      comments.insert(self.scanner.token_start(), current_comments);
     }
 
-    if let Some(token) = &token {
-      if self.tokens.is_some() {
-        self.capture_token(token.clone());
-      }
+    if let Some(token) = &token
+      && self.tokens.is_some()
+    {
+      self.capture_token(token.clone());
     }
 
     Ok(token)
@@ -257,7 +257,7 @@ fn parse_value<'a>(context: &mut Context<'a>) -> Result<Option<Value<'a>>, Parse
       Token::String(value) => Ok(Some(Value::StringLit(create_string_lit(context, value)))),
       Token::Boolean(value) => Ok(Some(Value::BooleanLit(create_boolean_lit(context, value)))),
       Token::Number(value) => Ok(Some(Value::NumberLit(create_number_lit(context, value)))),
-      Token::Null => return Ok(Some(Value::NullKeyword(create_null_keyword(context)))),
+      Token::Null => Ok(Some(Value::NullKeyword(create_null_keyword(context)))),
       Token::CloseBracket => Err(context.create_error(ParseErrorKind::UnexpectedCloseBracket)),
       Token::CloseBrace => Err(context.create_error(ParseErrorKind::UnexpectedCloseBrace)),
       Token::Comma => Err(context.create_error(ParseErrorKind::UnexpectedComma)),
@@ -292,10 +292,10 @@ fn parse_object<'a>(context: &mut Context<'a>) -> Result<Object<'a>, ParseError>
     // skip the comma
     if let Some(Token::Comma) = context.scan()? {
       let comma_range = context.create_range_from_last_token();
-      if let Some(Token::CloseBrace) = context.scan()? {
-        if !context.allow_trailing_commas {
-          return Err(context.create_error_for_range(comma_range, ParseErrorKind::TrailingCommasNotAllowed));
-        }
+      if let Some(Token::CloseBrace) = context.scan()?
+        && !context.allow_trailing_commas
+      {
+        return Err(context.create_error_for_range(comma_range, ParseErrorKind::TrailingCommasNotAllowed));
       }
     }
   }
@@ -363,10 +363,10 @@ fn parse_array<'a>(context: &mut Context<'a>) -> Result<Array<'a>, ParseError> {
     // skip the comma
     if let Some(Token::Comma) = context.scan()? {
       let comma_range = context.create_range_from_last_token();
-      if let Some(Token::CloseBracket) = context.scan()? {
-        if !context.allow_trailing_commas {
-          return Err(context.create_error_for_range(comma_range, ParseErrorKind::TrailingCommasNotAllowed));
-        }
+      if let Some(Token::CloseBracket) = context.scan()?
+        && !context.allow_trailing_commas
+      {
+        return Err(context.create_error_for_range(comma_range, ParseErrorKind::TrailingCommasNotAllowed));
       }
     }
   }
@@ -573,4 +573,46 @@ mod tests {
   fn error_correct_line_column_unicode_width() {
     assert_has_strict_error(r#"["🧑‍🦰", ["#, "Unterminated array on line 1 column 10");
   }
+
+  #[test]
+  fn it_should_parse_unquoted_keys_with_hex_and_trailing_comma() {
+    let text = r#"{
+      CP_CanFuncReqId: 0x7DF,  // 2015
+  }"#;
+    {
+      let parse_result = parse_to_ast(text, &Default::default(), &Default::default()).unwrap();
+
+      let value = parse_result.value.unwrap();
+      let obj = value.as_object().unwrap();
+      assert_eq!(obj.properties.len(), 1);
+      assert_eq!(obj.properties[0].name.as_str(), "CP_CanFuncReqId");
+
+      let number_value = obj.properties[0].value.as_number_lit().unwrap();
+      assert_eq!(number_value.value, "0x7DF");
+    }
+    #[cfg(feature = "serde")]
+    {
+      let value = crate::parse_to_serde_value(text, &Default::default()).unwrap().unwrap();
+      // hexadecimal numbers are converted to decimal in serde output
+      assert_eq!(
+        value,
+        serde_json::json!({
+          "CP_CanFuncReqId": 2015
+        })
+      );
+    }
+  }
+
+  #[test]
+  fn it_should_parse_unary_plus_numbers() {
+    let result = parse_to_ast(r#"{ "test": +42 }"#, &Default::default(), &Default::default()).unwrap();
+
+    let value = result.value.unwrap();
+    let obj = value.as_object().unwrap();
+    assert_eq!(obj.properties.len(), 1);
+    assert_eq!(obj.properties[0].name.as_str(), "test");
+
+    let number_value = obj.properties[0].value.as_number_lit().unwrap();
+    assert_eq!(number_value.value, "+42");
+  }
 }
